@@ -1,4 +1,4 @@
-;;; riece-globals.el --- global variables and constants.
+;;; riece-globals.el --- global variables and constants. -*- lexical-binding: t -*-
 ;; Copyright (C) 1998-2003 Daiki Ueno
 
 ;; Author: Daiki Ueno <ueno@unixuser.org>
@@ -113,6 +113,9 @@ Local to the server buffers.")
 (defvar riece-read-point nil
   "Point at the last input was seen.
 Local to the server buffers.")
+(defvar riece-filter-running nil
+  "Lock of the process filter; non-nil indicates the process filter is running.
+Local to the server buffers.")
 (defvar riece-send-queue nil
   "Send queue for avoiding client flood.
 Local to the server buffers.")
@@ -155,26 +158,34 @@ Local to the channel buffers.")
 
 ;;; Modeline indicators:
 (defvar riece-mode-line-buffer-identification nil)
+(put 'riece-mode-line-buffer-identification 'risky-local-variable t)
 (defvar riece-channel-indicator "None"
   "String displayed on the modeline to indicate the current channel.")
+(put 'riece-channel-indicator 'risky-local-variable t)
 (defvar riece-long-channel-indicator "None"
   "String displayed on the modeline to indicate the current channel.
 Generally, this string will contain more information than
 riece-channel-indicator.")
+(put 'riece-long-channel-indicator 'risky-local-variable t)
 (defvar riece-channel-list-indicator "No channel"
   "String displayed on the modeline to show the joined channels.")
+(put 'riece-channel-list-indicator 'risky-local-variable t)
 (defvar riece-user-indicator nil
   "String displayed on the modeline to show the current nickname.")
+(put 'riece-user-indicator 'risky-local-variable t)
 
 (defvar riece-away-indicator "-"
   "String displayed on the modeline to allow the user to tell if the
 user is away.")
+(put 'riece-away-indicator 'risky-local-variable t)
 (defvar riece-operator-indicator "-"
   "String displayed on the modeline to allow the user to tell if the
 user is an operator.")
+(put 'riece-operator-indicator 'risky-local-variable t)
 (defvar riece-channel-status-indicator "-"
   "String displayed on the modeline to allow the user to tell if the
 user's status on the current channel.")
+(put 'riece-channel-status-indicator 'risky-local-variable t)
 
 ;;; Buffers:
 (defvar riece-command-buffer nil
